@@ -6,9 +6,8 @@
 
 import re
 
-from rocm_docs import ROCmDocs
-with open('../CMakeLists.txt', encoding='utf-8') as f:
-    match = re.search(r'rocm_setup_version\(VERSION\s+\"?([0-9.]+)[^0-9.]+', f.read())
+with open("../CMakeLists.txt", encoding="utf-8") as f:
+    match = re.search(r"rocm_setup_version\(VERSION\s+\"?([0-9.]+)[^0-9.]+", f.read())
     if not match:
         raise ValueError("VERSION not found!")
     version_number = match[1]
@@ -17,19 +16,22 @@ left_nav_title = f"rocThrust {version_number} Documentation"
 # for PDF output on Read the Docs
 project = "rocThrust Documentation"
 author = "Advanced Micro Devices, Inc."
-copyright = "Copyright (c) 2024 Advanced Micro Devices, Inc. All rights reserved."
+copyright = "Copyright (c) 2024-2025 Advanced Micro Devices, Inc. All rights reserved."
 version = version_number
 release = version_number
 
 external_toc_path = "./sphinx/_toc.yml"
 
-docs_core = ROCmDocs(left_nav_title)
-docs_core.run_doxygen(doxygen_root="doxygen", doxygen_path="doxygen/xml")
-docs_core.setup()
+extensions = ["rocm_docs", "rocm_docs.doxygen"]
+html_theme = "rocm_docs_theme"
+html_theme_options = {"flavor": "rocm"}
 
 external_projects_current_project = "rocthrust"
 
-for sphinx_var in ROCmDocs.SPHINX_VARS:
-    globals()[sphinx_var] = getattr(docs_core, sphinx_var)
+doxygen_root = "doxygen"
+doxygen_project = {
+    "name": project,
+    "path": "doxygen/xml",
+}
 
-cpp_id_attributes = ["__device__", "__host__"]
+cpp_id_attributes = ["__device__", "__host__", "THRUST_HOST_DEVICE", "THRUST_HOST", "THRUST_DEVICE"]
