@@ -1,7 +1,7 @@
 /*
  *  Copyright 2008-2019 NVIDIA Corporation
  *  Copyright 2013 Filipe RNC Maia
- *  Modifications Copyright© 2019-2024 Advanced Micro Devices, Inc. All rights reserved. 
+ *  Modifications Copyright© 2019-2025 Advanced Micro Devices, Inc. All rights reserved.
  *
  *  Licensed under the Apache License, Version 2.0 (the "License");
  *  you may not use this file except in compliance with the License.
@@ -24,26 +24,18 @@
 
 #include <thrust/detail/config.h>
 
+#include <thrust/detail/type_traits.h>
+
 #include <cmath>
 #include <complex>
 #include <sstream>
-#include <thrust/detail/type_traits.h>
+#include <type_traits>
 
-#if THRUST_CPP_DIALECT >= 2011
-#  define THRUST_STD_COMPLEX_REAL(z) \
-    reinterpret_cast< \
-      const typename thrust::detail::remove_reference<decltype(z)>::type::value_type (&)[2] \
-    >(z)[0]
-#  define THRUST_STD_COMPLEX_IMAG(z) \
-    reinterpret_cast< \
-      const typename thrust::detail::remove_reference<decltype(z)>::type::value_type (&)[2] \
-    >(z)[1]
-#  define THRUST_STD_COMPLEX_DEVICE __device__
-#else
-#  define THRUST_STD_COMPLEX_REAL(z) (z).real()
-#  define THRUST_STD_COMPLEX_IMAG(z) (z).imag()
-#  define THRUST_STD_COMPLEX_DEVICE
-#endif
+#define THRUST_STD_COMPLEX_REAL(z) \
+  reinterpret_cast<const typename thrust::detail::remove_reference<decltype(z)>::type::value_type(&)[2]>(z)[0]
+#define THRUST_STD_COMPLEX_IMAG(z) \
+  reinterpret_cast<const typename thrust::detail::remove_reference<decltype(z)>::type::value_type(&)[2]>(z)[1]
+#define THRUST_STD_COMPLEX_DEVICE THRUST_DEVICE
 
 THRUST_NAMESPACE_BEGIN
 
@@ -54,7 +46,6 @@ THRUST_NAMESPACE_BEGIN
  *  fail to match the template, and give up looking for other scopes.
  */
 
-
 /*! \addtogroup numerics
  *  \{
  */
@@ -63,86 +54,6 @@ THRUST_NAMESPACE_BEGIN
  *  \{
  */
 
-/*! \cond
- */
-
-namespace detail
-{
-
-template <typename T, std::size_t Align>
-struct complex_storage;
-
-#if THRUST_CPP_DIALECT >= 2011                                                    \
-  && (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_GCC)                       \
-  && (THRUST_GCC_VERSION >= 40800)
-  // C++11 implementation, excluding GCC 4.7, which doesn't have `alignas`.
-  template <typename T, std::size_t Align>
-  struct complex_storage
-  {
-    struct alignas(Align) type { T x; T y; };
-  };
-#elif  (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_MSVC)                    \
-    || (   (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_GCC)                 \
-        && (THRUST_GCC_VERSION < 40600))
-  // C++03 implementation for MSVC and GCC <= 4.5.
-  //
-  // We have to implement `aligned_type` with specializations for MSVC
-  // and GCC 4.2 and older because they require literals as arguments to
-  // their alignment attribute.
-
-  #if (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_MSVC)
-    // MSVC implementation.
-    #define THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(X)                   \
-      template <typename T>                                                   \
-      struct complex_storage<T, X>                                            \
-      {                                                                       \
-        __declspec(align(X)) struct type { T x; T y; };                       \
-      };                                                                      \
-      /**/
-  #else
-    // GCC <= 4.2 implementation.
-    #define THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(X)                   \
-      template <typename T>                                                   \
-      struct complex_storage<T, X>                                            \
-      {                                                                       \
-        struct type { T x; T y; } __attribute__((aligned(X)));                \
-      };                                                                      \
-      /**/
-  #endif
-
-  // The primary template is a fallback, which doesn't specify any alignment.
-  // It's only used when T is very large and we're using an older compilers
-  // which we have to fully specialize each alignment case.
-  template <typename T, std::size_t Align>
-  struct complex_storage
-  {
-    T x; T y;
-  };
-
-  THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(1);
-  THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(2);
-  THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(4);
-  THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(8);
-  THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(16);
-  THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(32);
-  THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(64);
-  THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION(128);
-
-  #undef THRUST_DEFINE_COMPLEX_STORAGE_SPECIALIZATION
-#else
-  // C++03 implementation for GCC > 4.5, Clang, PGI, ICPC, and xlC.
-  template <typename T, std::size_t Align>
-  struct complex_storage
-  {
-    struct type { T x; T y; } __attribute__((aligned(Align)));
-  };
-#endif
-
-} // end namespace detail
-
-/*! \endcond
- */
-
 /*! \p complex is the Thrust equivalent to <tt>std::complex</tt>. It is
  *  functionally identical to it, but can also be used in device code which
  *  <tt>std::complex</tt> currently cannot.
@@ -155,12 +66,9 @@ template <typename T>
 struct complex
 {
 public:
-
   /*! \p value_type is the type of \p complex's real and imaginary parts.
    */
-  typedef T value_type;
-
-
+  using value_type = T;
 
   /* --- Constructors --- */
 
@@ -168,18 +76,15 @@ public:
    *
    *  \param re The real part of the number.
    */
-  __host__ __device__
-  complex(const T& re);
+  THRUST_HOST_DEVICE complex(const T& re);
 
   /*! Construct a complex number from its real and imaginary parts.
    *
    *  \param re The real part of the number.
    *  \param im The imaginary part of the number.
    */
-  __host__ __device__
-  complex(const T& re, const T& im);
+  THRUST_HOST_DEVICE complex(const T& re, const T& im);
 
-#if THRUST_CPP_DIALECT >= 2011
   /*! Default construct a complex number.
    */
   complex() = default;
@@ -190,20 +95,6 @@ public:
    *  \param z The \p complex to copy from.
    */
   complex(const complex<T>& z) = default;
-#else
-  /*! Default construct a complex number.
-   */
-  __host__ __device__
-  complex();
-
-  /*! This copy constructor copies from a \p complex with a type that is
-   *  convertible to this \p complex's \c value_type.
-   *
-   *  \param z The \p complex to copy from.
-   */
-  __host__ __device__
-  complex(const complex<T>& z);
-#endif
 
   /*! This converting copy constructor copies from a \p complex with a type
    *  that is convertible to this \p complex's \c value_type.
@@ -213,16 +104,14 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ __device__
-  complex(const complex<U>& z);
+  THRUST_HOST_DEVICE complex(const complex<U>& z);
 
   /*! This converting copy constructor copies from a <tt>std::complex</tt> with
    *  a type that is convertible to this \p complex's \c value_type.
    *
    *  \param z The \p complex to copy from.
    */
-  __host__ THRUST_STD_COMPLEX_DEVICE
-  complex(const std::complex<T>& z);
+  THRUST_HOST THRUST_STD_COMPLEX_DEVICE complex(const std::complex<T>& z);
 
   /*! This converting copy constructor copies from a <tt>std::complex</tt> with
    *  a type that is convertible to this \p complex's \c value_type.
@@ -232,10 +121,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ THRUST_STD_COMPLEX_DEVICE
-  complex(const std::complex<U>& z);
-
-
+  THRUST_HOST THRUST_STD_COMPLEX_DEVICE complex(const std::complex<U>& z);
 
   /* --- Assignment Operators --- */
 
@@ -244,25 +130,14 @@ public:
    *
    *  \param re The real part of the number.
    */
-  __host__ __device__
-  complex& operator=(const T& re);
+  THRUST_HOST_DEVICE complex& operator=(const T& re);
 
-#if THRUST_CPP_DIALECT >= 2011
   /*! Assign `z.real()` and `z.imag()` to the real and imaginary parts of this
    *  \p complex respectively.
    *
    *  \param z The \p complex to copy from.
    */
   complex& operator=(const complex<T>& z) = default;
-#else
-  /*! Assign `z.real()` and `z.imag()` to the real and imaginary parts of this
-   *  \p complex respectively.
-   *
-   *  \param z The \p complex to copy from.
-   */
-  __host__ __device__
-  complex& operator=(const complex<T>& z);
-#endif
 
   /*! Assign `z.real()` and `z.imag()` to the real and imaginary parts of this
    *  \p complex respectively.
@@ -272,16 +147,14 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ __device__
-  complex& operator=(const complex<U>& z);
+  THRUST_HOST_DEVICE complex& operator=(const complex<U>& z);
 
   /*! Assign `z.real()` and `z.imag()` to the real and imaginary parts of this
    *  \p complex respectively.
    *
    *  \param z The \p complex to copy from.
    */
-  __host__ THRUST_STD_COMPLEX_DEVICE
-  complex& operator=(const std::complex<T>& z);
+  THRUST_HOST THRUST_STD_COMPLEX_DEVICE complex& operator=(const std::complex<T>& z);
 
   /*! Assign `z.real()` and `z.imag()` to the real and imaginary parts of this
    *  \p complex respectively.
@@ -291,9 +164,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ THRUST_STD_COMPLEX_DEVICE
-  complex& operator=(const std::complex<U>& z);
-
+  THRUST_HOST THRUST_STD_COMPLEX_DEVICE complex& operator=(const std::complex<U>& z);
 
   /* --- Compound Assignment Operators --- */
 
@@ -305,8 +176,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ __device__
-  complex<T>& operator+=(const complex<U>& z);
+  THRUST_HOST_DEVICE complex<T>& operator+=(const complex<U>& z);
 
   /*! Subtracts a \p complex from this \p complex and assigns the result to
    *  this \p complex.
@@ -316,8 +186,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ __device__
-  complex<T>& operator-=(const complex<U>& z);
+  THRUST_HOST_DEVICE complex<T>& operator-=(const complex<U>& z);
 
   /*! Multiplies this \p complex by another \p complex and assigns the result
    *  to this \p complex.
@@ -327,8 +196,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ __device__
-  complex<T>& operator*=(const complex<U>& z);
+  THRUST_HOST_DEVICE complex<T>& operator*=(const complex<U>& z);
 
   /*! Divides this \p complex by another \p complex and assigns the result to
    *  this \p complex.
@@ -338,8 +206,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ __device__
-  complex<T>& operator/=(const complex<U>& z);
+  THRUST_HOST_DEVICE complex<T>& operator/=(const complex<U>& z);
 
   /*! Adds a scalar to this \p complex and assigns the result to this
    *  \p complex.
@@ -349,8 +216,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ __device__
-  complex<T>& operator+=(const U& z);
+  THRUST_HOST_DEVICE complex<T>& operator+=(const U& z);
 
   /*! Subtracts a scalar from this \p complex and assigns the result to
    *  this \p complex.
@@ -360,8 +226,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ __device__
-  complex<T>& operator-=(const U& z);
+  THRUST_HOST_DEVICE complex<T>& operator-=(const U& z);
 
   /*! Multiplies this \p complex by a scalar and assigns the result
    *  to this \p complex.
@@ -371,8 +236,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ __device__
-  complex<T>& operator*=(const U& z);
+  THRUST_HOST_DEVICE complex<T>& operator*=(const U& z);
 
   /*! Divides this \p complex by a scalar and assigns the result to
    *  this \p complex.
@@ -382,10 +246,7 @@ public:
    *  \tparam U is convertible to \c value_type.
    */
   template <typename U>
-  __host__ __device__
-  complex<T>& operator/=(const U& z);
-
-
+  THRUST_HOST_DEVICE complex<T>& operator/=(const U& z);
 
   /* --- Getter functions ---
    * The volatile ones are there to help for example
@@ -394,25 +255,31 @@ public:
 
   /*! Returns the real part of this \p complex.
    */
-  __host__ __device__
-  T real() const volatile { return data.x; }
+  THRUST_HOST_DEVICE T real() const volatile
+  {
+    return data.x;
+  }
 
   /*! Returns the imaginary part of this \p complex.
    */
-  __host__ __device__
-  T imag() const volatile { return data.y; }
+  THRUST_HOST_DEVICE T imag() const volatile
+  {
+    return data.y;
+  }
 
   /*! Returns the real part of this \p complex.
    */
-  __host__ __device__
-  T real() const { return data.x; }
+  THRUST_HOST_DEVICE T real() const
+  {
+    return data.x;
+  }
 
   /*! Returns the imaginary part of this \p complex.
    */
-  __host__ __device__
-  T imag() const { return data.y; }
-
-
+  THRUST_HOST_DEVICE T imag() const
+  {
+    return data.y;
+  }
 
   /* --- Setter functions ---
    * The volatile ones are there to help for example
@@ -423,43 +290,69 @@ public:
    *
    *  \param re The new real part of this \p complex.
    */
-  __host__ __device__
-  void real(T re) volatile { data.x = re; }
+  THRUST_HOST_DEVICE void real(T re) volatile
+  {
+    data.x = re;
+  }
 
   /*! Sets the imaginary part of this \p complex.
    *
    *  \param im The new imaginary part of this \p complex.e
    */
-  __host__ __device__
-  void imag(T im) volatile { data.y = im; }
+  THRUST_HOST_DEVICE void imag(T im) volatile
+  {
+    data.y = im;
+  }
 
   /*! Sets the real part of this \p complex.
    *
    *  \param re The new real part of this \p complex.
    */
-  __host__ __device__
-  void real(T re) { data.x = re; }
+  THRUST_HOST_DEVICE void real(T re)
+  {
+    data.x = re;
+  }
 
   /*! Sets the imaginary part of this \p complex.
    *
    *  \param im The new imaginary part of this \p complex.
    */
-  __host__ __device__
-  void imag(T im) { data.y = im; }
-
-
+  THRUST_HOST_DEVICE void imag(T im)
+  {
+    data.y = im;
+  }
 
   /* --- Casting functions --- */
 
   /*! Casts this \p complex to a <tt>std::complex</tt> of the same type.
    */
-  __host__
-  operator std::complex<T>() const { return std::complex<T>(real(), imag()); }
+  THRUST_HOST operator std::complex<T>() const
+  {
+    return std::complex<T>(real(), imag());
+  }
 
 private:
-  typename detail::complex_storage<T, sizeof(T) * 2>::type data;
-};
+/**
+ * @brief Storage of two \p complex numbers.
+ */
+#if defined(__CUDACC__) && ((__CUDACC_VER_MAJOR__ < 11) || (__CUDACC_VER_MAJOR__ == 11 && __CUDACC_VER_MINOR__ < 7))
+  struct __align__(sizeof(T) * 2) storage
+#elif (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_ICC)
+  struct storage
+#else
+  struct alignas(sizeof(T) * 2) storage
+#endif
+  {
+    T x; /**< @brief The first \p complex. */
+    T y; /**< @brief The second \p complex. */
+  }
+#if (THRUST_HOST_COMPILER == THRUST_HOST_COMPILER_ICC)
+  __attribute__((aligned(sizeof(T) * 2)))
+#endif
 
+  ;
+  storage data;
+};
 
 /* --- General Functions --- */
 
@@ -467,33 +360,29 @@ private:
  *
  *  \param z The \p complex from which to calculate the absolute value.
  */
-template<typename T>
-__host__ __device__
-T abs(const complex<T>& z);
+template <typename T>
+THRUST_HOST_DEVICE T abs(const complex<T>& z);
 
 /*! Returns the phase angle (also known as argument) in radians of a \p complex.
  *
  *  \param z The \p complex from which to calculate the phase angle.
  */
 template <typename T>
-__host__ __device__
-T arg(const complex<T>& z);
+THRUST_HOST_DEVICE T arg(const complex<T>& z);
 
 /*! Returns the square of the magnitude of a \p complex.
  *
  *  \param z The \p complex from which to calculate the norm.
  */
 template <typename T>
-__host__ __device__
-T norm(const complex<T>& z);
+THRUST_HOST_DEVICE T norm(const complex<T>& z);
 
 /*! Returns the complex conjugate of a \p complex.
  *
  *  \param z The \p complex from which to calculate the complex conjugate.
  */
 template <typename T>
-__host__ __device__
-complex<T> conj(const complex<T>& z);
+THRUST_HOST_DEVICE complex<T> conj(const complex<T>& z);
 
 /*! Returns a \p complex with the specified magnitude and phase.
  *
@@ -501,8 +390,7 @@ complex<T> conj(const complex<T>& z);
  *  \param theta The phase of the returned \p complex in radians.
  */
 template <typename T0, typename T1>
-__host__ __device__
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
+THRUST_HOST_DEVICE complex<typename detail::promoted_numerical_type<T0, T1>::type>
 polar(const T0& m, const T1& theta = T1());
 
 /*! Returns the projection of a \p complex on the Riemann sphere.
@@ -513,10 +401,7 @@ polar(const T0& m, const T1& theta = T1());
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
-complex<T> proj(const T& z);
-
-
+THRUST_HOST_DEVICE complex<T> proj(const T& z);
 
 /* --- Binary Arithmetic operators --- */
 
@@ -529,8 +414,7 @@ complex<T> proj(const T& z);
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-__host__ __device__
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
+THRUST_HOST_DEVICE complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator+(const complex<T0>& x, const complex<T1>& y);
 
 /*! Adds a scalar to a \p complex number.
@@ -542,8 +426,7 @@ operator+(const complex<T0>& x, const complex<T1>& y);
  *  \param y The scalar.
  */
 template <typename T0, typename T1>
-__host__ __device__
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
+THRUST_HOST_DEVICE complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator+(const complex<T0>& x, const T1& y);
 
 /*! Adds a \p complex number to a scalar.
@@ -555,8 +438,7 @@ operator+(const complex<T0>& x, const T1& y);
  *  \param y The \p complex.
  */
 template <typename T0, typename T1>
-__host__ __device__
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
+THRUST_HOST_DEVICE complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator+(const T0& x, const complex<T1>& y);
 
 /*! Subtracts two \p complex numbers.
@@ -568,8 +450,7 @@ operator+(const T0& x, const complex<T1>& y);
  *  \param y The second \p complex (subtrahend).
  */
 template <typename T0, typename T1>
-__host__ __device__
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
+THRUST_HOST_DEVICE complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator-(const complex<T0>& x, const complex<T1>& y);
 
 /*! Subtracts a scalar from a \p complex number.
@@ -581,8 +462,7 @@ operator-(const complex<T0>& x, const complex<T1>& y);
  *  \param y The scalar (subtrahend).
  */
 template <typename T0, typename T1>
-__host__ __device__
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
+THRUST_HOST_DEVICE complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator-(const complex<T0>& x, const T1& y);
 
 /*! Subtracts a \p complex number from a scalar.
@@ -594,8 +474,7 @@ operator-(const complex<T0>& x, const T1& y);
  *  \param y The \p complex (subtrahend).
  */
 template <typename T0, typename T1>
-__host__ __device__
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
+THRUST_HOST_DEVICE complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator-(const T0& x, const complex<T1>& y);
 
 /*! Multiplies two \p complex numbers.
@@ -607,8 +486,7 @@ operator-(const T0& x, const complex<T1>& y);
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-__host__ __device__
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
+THRUST_HOST_DEVICE complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator*(const complex<T0>& x, const complex<T1>& y);
 
 /*! Multiplies a \p complex number by a scalar.
@@ -617,8 +495,7 @@ operator*(const complex<T0>& x, const complex<T1>& y);
  *  \param y The scalar.
  */
 template <typename T0, typename T1>
-__host__ __device__
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
+THRUST_HOST_DEVICE complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator*(const complex<T0>& x, const T1& y);
 
 /*! Multiplies a scalar by a \p complex number.
@@ -630,8 +507,7 @@ operator*(const complex<T0>& x, const T1& y);
  *  \param y The \p complex.
  */
 template <typename T0, typename T1>
-__host__ __device__
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
+THRUST_HOST_DEVICE complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator*(const T0& x, const complex<T1>& y);
 
 /*! Divides two \p complex numbers.
@@ -643,8 +519,7 @@ operator*(const T0& x, const complex<T1>& y);
  *  \param y The denomimator (divisor).
  */
 template <typename T0, typename T1>
-__host__ __device__
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
+THRUST_HOST_DEVICE complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator/(const complex<T0>& x, const complex<T1>& y);
 
 /*! Divides a \p complex number by a scalar.
@@ -656,8 +531,7 @@ operator/(const complex<T0>& x, const complex<T1>& y);
  *  \param y The scalar denomimator (divisor).
  */
 template <typename T0, typename T1>
-__host__ __device__
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
+THRUST_HOST_DEVICE complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator/(const complex<T0>& x, const T1& y);
 
 /*! Divides a scalar by a \p complex number.
@@ -669,12 +543,9 @@ operator/(const complex<T0>& x, const T1& y);
  *  \param y The complex denomimator (divisor).
  */
 template <typename T0, typename T1>
-__host__ __device__
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
+THRUST_HOST_DEVICE complex<typename detail::promoted_numerical_type<T0, T1>::type>
 operator/(const T0& x, const complex<T1>& y);
 
-
-
 /* --- Unary Arithmetic operators --- */
 
 /*! Unary plus, returns its \p complex argument.
@@ -682,9 +553,7 @@ operator/(const T0& x, const complex<T1>& y);
  *  \param y The \p complex argument.
  */
 template <typename T>
-__host__ __device__
-complex<T>
-operator+(const complex<T>& y);
+THRUST_HOST_DEVICE complex<T> operator+(const complex<T>& y);
 
 /*! Unary minus, returns the additive inverse (negation) of its \p complex
  * argument.
@@ -692,11 +561,7 @@ operator+(const complex<T>& y);
  *  \param y The \p complex argument.
  */
 template <typename T>
-__host__ __device__
-complex<T>
-operator-(const complex<T>& y);
-
-
+THRUST_HOST_DEVICE complex<T> operator-(const complex<T>& y);
 
 /* --- Exponential Functions --- */
 
@@ -705,26 +570,21 @@ operator-(const complex<T>& y);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
-complex<T> exp(const complex<T>& z);
+THRUST_HOST_DEVICE complex<T> exp(const complex<T>& z);
 
 /*! Returns the complex natural logarithm of a \p complex number.
  *
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
-complex<T> log(const complex<T>& z);
+THRUST_HOST_DEVICE complex<T> log(const complex<T>& z);
 
 /*! Returns the complex base 10 logarithm of a \p complex number.
  *
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
-complex<T> log10(const complex<T>& z);
-
-
+THRUST_HOST_DEVICE complex<T> log10(const complex<T>& z);
 
 /* --- Power Functions --- */
 
@@ -737,8 +597,7 @@ complex<T> log10(const complex<T>& z);
  *  \param y The exponent.
  */
 template <typename T0, typename T1>
-__host__ __device__
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
+THRUST_HOST_DEVICE complex<typename detail::promoted_numerical_type<T0, T1>::type>
 pow(const complex<T0>& x, const complex<T1>& y);
 
 /*! Returns a \p complex number raised to a scalar.
@@ -750,8 +609,7 @@ pow(const complex<T0>& x, const complex<T1>& y);
  *  \param y The exponent.
  */
 template <typename T0, typename T1>
-__host__ __device__
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
+THRUST_HOST_DEVICE complex<typename detail::promoted_numerical_type<T0, T1>::type>
 pow(const complex<T0>& x, const T1& y);
 
 /*! Returns a scalar raised to a \p complex number.
@@ -763,8 +621,7 @@ pow(const complex<T0>& x, const T1& y);
  *  \param y The exponent.
  */
 template <typename T0, typename T1>
-__host__ __device__
-complex<typename detail::promoted_numerical_type<T0, T1>::type>
+THRUST_HOST_DEVICE complex<typename detail::promoted_numerical_type<T0, T1>::type>
 pow(const T0& x, const complex<T1>& y);
 
 /*! Returns the complex square root of a \p complex number.
@@ -772,9 +629,7 @@ pow(const T0& x, const complex<T1>& y);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
-complex<T> sqrt(const complex<T>& z);
-
+THRUST_HOST_DEVICE complex<T> sqrt(const complex<T>& z);
 
 /* --- Trigonometric Functions --- */
 
@@ -783,26 +638,21 @@ complex<T> sqrt(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
-complex<T> cos(const complex<T>& z);
+THRUST_HOST_DEVICE complex<T> cos(const complex<T>& z);
 
 /*! Returns the complex sine of a \p complex number.
  *
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
-complex<T> sin(const complex<T>& z);
+THRUST_HOST_DEVICE complex<T> sin(const complex<T>& z);
 
 /*! Returns the complex tangent of a \p complex number.
  *
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
-complex<T> tan(const complex<T>& z);
-
-
+THRUST_HOST_DEVICE complex<T> tan(const complex<T>& z);
 
 /* --- Hyperbolic Functions --- */
 
@@ -811,26 +661,21 @@ complex<T> tan(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
-complex<T> cosh(const complex<T>& z);
+THRUST_HOST_DEVICE complex<T> cosh(const complex<T>& z);
 
 /*! Returns the complex hyperbolic sine of a \p complex number.
  *
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
-complex<T> sinh(const complex<T>& z);
+THRUST_HOST_DEVICE complex<T> sinh(const complex<T>& z);
 
 /*! Returns the complex hyperbolic tangent of a \p complex number.
  *
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
-complex<T> tanh(const complex<T>& z);
-
-
+THRUST_HOST_DEVICE complex<T> tanh(const complex<T>& z);
 
 /* --- Inverse Trigonometric Functions --- */
 
@@ -842,8 +687,7 @@ complex<T> tanh(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
-complex<T> acos(const complex<T>& z);
+THRUST_HOST_DEVICE complex<T> acos(const complex<T>& z);
 
 /*! Returns the complex arc sine of a \p complex number.
  *
@@ -853,8 +697,7 @@ complex<T> acos(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
-complex<T> asin(const complex<T>& z);
+THRUST_HOST_DEVICE complex<T> asin(const complex<T>& z);
 
 /*! Returns the complex arc tangent of a \p complex number.
  *
@@ -864,10 +707,7 @@ complex<T> asin(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
-complex<T> atan(const complex<T>& z);
-
-
+THRUST_HOST_DEVICE complex<T> atan(const complex<T>& z);
 
 /* --- Inverse Hyperbolic Functions --- */
 
@@ -879,8 +719,7 @@ complex<T> atan(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
-complex<T> acosh(const complex<T>& z);
+THRUST_HOST_DEVICE complex<T> acosh(const complex<T>& z);
 
 /*! Returns the complex inverse hyperbolic sine of a \p complex number.
  *
@@ -890,8 +729,7 @@ complex<T> acosh(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
-complex<T> asinh(const complex<T>& z);
+THRUST_HOST_DEVICE complex<T> asinh(const complex<T>& z);
 
 /*! Returns the complex inverse hyperbolic tangent of a \p complex number.
  *
@@ -901,10 +739,7 @@ complex<T> asinh(const complex<T>& z);
  *  \param z The \p complex argument.
  */
 template <typename T>
-__host__ __device__
-complex<T> atanh(const complex<T>& z);
-
-
+THRUST_HOST_DEVICE complex<T> atanh(const complex<T>& z);
 
 /* --- Stream Operators --- */
 
@@ -914,8 +749,7 @@ complex<T> atanh(const complex<T>& z);
  *  \param z The \p complex number to output.
  */
 template <typename T, typename CharT, typename Traits>
-std::basic_ostream<CharT, Traits>&
-operator<<(std::basic_ostream<CharT, Traits>& os, const complex<T>& z);
+std::basic_ostream<CharT, Traits>& operator<<(std::basic_ostream<CharT, Traits>& os, const complex<T>& z);
 
 /*! Reads a \p complex number from an input stream.
  *
@@ -930,11 +764,7 @@ operator<<(std::basic_ostream<CharT, Traits>& os, const complex<T>& z);
  *  \param z The \p complex number to set.
  */
 template <typename T, typename CharT, typename Traits>
-__host__
-std::basic_istream<CharT, Traits>&
-operator>>(std::basic_istream<CharT, Traits>& is, complex<T>& z);
-
-
+THRUST_HOST std::basic_istream<CharT, Traits>& operator>>(std::basic_istream<CharT, Traits>& is, complex<T>& z);
 
 /* --- Equality Operators --- */
 
@@ -944,8 +774,7 @@ operator>>(std::basic_istream<CharT, Traits>& is, complex<T>& z);
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-__host__ __device__
-bool operator==(const complex<T0>& x, const complex<T1>& y);
+THRUST_HOST_DEVICE bool operator==(const complex<T0>& x, const complex<T1>& y);
 
 /*! Returns true if two \p complex numbers are equal and false otherwise.
  *
@@ -953,8 +782,7 @@ bool operator==(const complex<T0>& x, const complex<T1>& y);
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-__host__ THRUST_STD_COMPLEX_DEVICE
-bool operator==(const complex<T0>& x, const std::complex<T1>& y);
+THRUST_HOST THRUST_STD_COMPLEX_DEVICE bool operator==(const complex<T0>& x, const std::complex<T1>& y);
 
 /*! Returns true if two \p complex numbers are equal and false otherwise.
  *
@@ -962,8 +790,7 @@ bool operator==(const complex<T0>& x, const std::complex<T1>& y);
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-__host__ THRUST_STD_COMPLEX_DEVICE
-bool operator==(const std::complex<T0>& x, const complex<T1>& y);
+THRUST_HOST THRUST_STD_COMPLEX_DEVICE bool operator==(const std::complex<T0>& x, const complex<T1>& y);
 
 /*! Returns true if the imaginary part of the \p complex number is zero and
  *  the real part is equal to the scalar. Returns false otherwise.
@@ -972,8 +799,7 @@ bool operator==(const std::complex<T0>& x, const complex<T1>& y);
  *  \param y The \p complex.
  */
 template <typename T0, typename T1>
-__host__ __device__
-bool operator==(const T0& x, const complex<T1>& y);
+THRUST_HOST_DEVICE bool operator==(const T0& x, const complex<T1>& y);
 
 /*! Returns true if the imaginary part of the \p complex number is zero and
  *  the real part is equal to the scalar. Returns false otherwise.
@@ -982,8 +808,7 @@ bool operator==(const T0& x, const complex<T1>& y);
  *  \param y The scalar.
  */
 template <typename T0, typename T1>
-__host__ __device__
-bool operator==(const complex<T0>& x, const T1& y);
+THRUST_HOST_DEVICE bool operator==(const complex<T0>& x, const T1& y);
 
 /*! Returns true if two \p complex numbers are different and false otherwise.
  *
@@ -991,8 +816,7 @@ bool operator==(const complex<T0>& x, const T1& y);
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-__host__ __device__
-bool operator!=(const complex<T0>& x, const complex<T1>& y);
+THRUST_HOST_DEVICE bool operator!=(const complex<T0>& x, const complex<T1>& y);
 
 /*! Returns true if two \p complex numbers are different and false otherwise.
  *
@@ -1000,8 +824,7 @@ bool operator!=(const complex<T0>& x, const complex<T1>& y);
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-__host__ THRUST_STD_COMPLEX_DEVICE
-bool operator!=(const complex<T0>& x, const std::complex<T1>& y);
+THRUST_HOST THRUST_STD_COMPLEX_DEVICE bool operator!=(const complex<T0>& x, const std::complex<T1>& y);
 
 /*! Returns true if two \p complex numbers are different and false otherwise.
  *
@@ -1009,8 +832,7 @@ bool operator!=(const complex<T0>& x, const std::complex<T1>& y);
  *  \param y The second \p complex.
  */
 template <typename T0, typename T1>
-__host__ THRUST_STD_COMPLEX_DEVICE
-bool operator!=(const std::complex<T0>& x, const complex<T1>& y);
+THRUST_HOST THRUST_STD_COMPLEX_DEVICE bool operator!=(const std::complex<T0>& x, const complex<T1>& y);
 
 /*! Returns true if the imaginary part of the \p complex number is not zero or
  *  the real part is different from the scalar. Returns false otherwise.
@@ -1019,8 +841,7 @@ bool operator!=(const std::complex<T0>& x, const complex<T1>& y);
  *  \param y The \p complex.
  */
 template <typename T0, typename T1>
-__host__ __device__
-bool operator!=(const T0& x, const complex<T1>& y);
+THRUST_HOST_DEVICE bool operator!=(const T0& x, const complex<T1>& y);
 
 /*! Returns true if the imaginary part of the \p complex number is not zero or
  *  the real part is different from the scalar. Returns false otherwise.
@@ -1029,8 +850,7 @@ bool operator!=(const T0& x, const complex<T1>& y);
  *  \param y The scalar.
  */
 template <typename T0, typename T1>
-__host__ __device__
-bool operator!=(const complex<T0>& x, const T1& y);
+THRUST_HOST_DEVICE bool operator!=(const complex<T0>& x, const T1& y);
 
 THRUST_NAMESPACE_END
 
