@@ -14,7 +14,6 @@
  *  limitations under the License.
  */
 
-
 /*! \file
  *  \brief A dynamically-sizable array of elements which resides in memory
  *         accessible to devices.
@@ -23,12 +22,13 @@
 #pragma once
 
 #include <thrust/detail/config.h>
+
 #include <thrust/detail/vector_base.h>
 #include <thrust/device_allocator.h>
 
 #include <initializer_list>
-#include <vector>
 #include <utility>
+#include <vector>
 
 THRUST_NAMESPACE_BEGIN
 
@@ -48,194 +48,224 @@ THRUST_NAMESPACE_BEGIN
  *  \see host_vector
  *  \see universal_vector
  */
-template<typename T, typename Alloc = thrust::device_allocator<T> >
-  class device_vector
-    : public detail::vector_base<T,Alloc>
+template <typename T, typename Alloc = thrust::device_allocator<T>>
+class device_vector : public detail::vector_base<T, Alloc>
 {
-  private:
-    typedef detail::vector_base<T,Alloc> Parent;
+private:
+  using Parent = detail::vector_base<T, Alloc>;
 
-  public:
-    /*! \cond
-     */
-    typedef typename Parent::size_type  size_type;
-    typedef typename Parent::value_type value_type;
-    /*! \endcond
-     */
+public:
+  /*! \cond
+   */
+  using size_type  = typename Parent::size_type;
+  using value_type = typename Parent::value_type;
+  /*! \endcond
+   */
 
-    /*! This constructor creates an empty \p device_vector.
-     */
-    device_vector(void)
-      :Parent() {}
+  /*! This constructor creates an empty \p device_vector.
+   */
+  device_vector(void)
+      : Parent()
+  {}
 
-    /*! This constructor creates an empty \p device_vector.
-     *  \param alloc The allocator to use by this device_vector.
-     */
-    device_vector(const Alloc &alloc)
-      :Parent(alloc) {}
+  /*! This constructor creates an empty \p device_vector.
+   *  \param alloc The allocator to use by this device_vector.
+   */
+  device_vector(const Alloc& alloc)
+      : Parent(alloc)
+  {}
 
-    /*! The destructor erases the elements.
-     */
-    //  Define an empty destructor to explicitly specify
-    //  its execution space qualifier, as a workaround for nvcc warning
-    ~device_vector(void) {}
+  /*! The destructor erases the elements.
+   */
+  //  Define an empty destructor to explicitly specify
+  //  its execution space qualifier, as a workaround for nvcc warning
+  ~device_vector(void) {}
 
-    /*! This constructor creates a \p device_vector with the given
-     *  size.
-     *  \param n The number of elements to initially create.
-     */
-    explicit device_vector(size_type n)
-      :Parent(n) {}
+  /*! This constructor creates a \p device_vector with the given
+   *  size.
+   *  \param n The number of elements to initially create.
+   */
+  explicit device_vector(size_type n)
+      : Parent(n)
+  {}
 
-    /*! This constructor creates a \p device_vector with the given
-     *  size.
-     *  \param n The number of elements to initially create.
-     *  \param alloc The allocator to use by this device_vector.
-     */
-    explicit device_vector(size_type n, const Alloc &alloc)
-      :Parent(n,alloc) {}
+  /*! This constructor creates a \p device_vector with the given
+   *  size.
+   *  \param n The number of elements to initially create.
+   *  \param alloc The allocator to use by this device_vector.
+   */
+  explicit device_vector(size_type n, const Alloc& alloc)
+      : Parent(n, alloc)
+  {}
 
-    /*! This constructor creates a \p device_vector with copies
-     *  of an exemplar element.
-     *  \param n The number of elements to initially create.
-     *  \param value An element to copy.
-     */
-    explicit device_vector(size_type n, const value_type &value)
-      :Parent(n,value) {}
+  /*! This constructor creates a \p device_vector with copies
+   *  of an exemplar element.
+   *  \param n The number of elements to initially create.
+   *  \param value An element to copy.
+   */
+  explicit device_vector(size_type n, const value_type& value)
+      : Parent(n, value)
+  {}
 
-    /*! This constructor creates a \p device_vector with copies
-     *  of an exemplar element.
-     *  \param n The number of elements to initially create.
-     *  \param value An element to copy.
-     *  \param alloc The allocator to use by this device_vector.
-     */
-    explicit device_vector(size_type n, const value_type &value, const Alloc &alloc)
-      :Parent(n,value,alloc) {}
+  /*! This constructor creates a \p device_vector with copies
+   *  of an exemplar element.
+   *  \param n The number of elements to initially create.
+   *  \param value An element to copy.
+   *  \param alloc The allocator to use by this device_vector.
+   */
+  explicit device_vector(size_type n, const value_type& value, const Alloc& alloc)
+      : Parent(n, value, alloc)
+  {}
 
-    /*! Copy constructor copies from an exemplar \p device_vector.
-     *  \param v The \p device_vector to copy.
-     */
-    device_vector(const device_vector &v)
-      :Parent(v) {}
+  /*! Copy constructor copies from an exemplar \p device_vector.
+   *  \param v The \p device_vector to copy.
+   */
+  device_vector(const device_vector& v)
+      : Parent(v)
+  {}
 
-    /*! Copy constructor copies from an exemplar \p device_vector.
-     *  \param v The \p device_vector to copy.
-     *  \param alloc The allocator to use by this device_vector.
-     */
-    device_vector(const device_vector &v, const Alloc &alloc)
-      :Parent(v,alloc) {}
+  /*! Copy constructor copies from an exemplar \p device_vector.
+   *  \param v The \p device_vector to copy.
+   *  \param alloc The allocator to use by this device_vector.
+   */
+  device_vector(const device_vector& v, const Alloc& alloc)
+      : Parent(v, alloc)
+  {}
 
-  #if THRUST_CPP_DIALECT >= 2011
-    /*! Move constructor moves from another \p device_vector.
-     *  \param v The device_vector to move.
-     */
-    device_vector(device_vector &&v)
-      :Parent(std::move(v)) {}
+  /*! Move constructor moves from another \p device_vector.
+   *  \param v The device_vector to move.
+   */
+  device_vector(device_vector&& v)
+      : Parent(std::move(v))
+  {}
 
-    /*! Move constructor moves from another \p device_vector.
-     *  \param v The device_vector to move.
-     *  \param alloc The allocator to use by this device_vector.
-     */
-    device_vector(device_vector &&v, const Alloc &alloc)
-      :Parent(std::move(v), alloc) {}
-  #endif // THRUST_CPP_DIALECT >= 2011
+  /*! Move constructor moves from another \p device_vector.
+   *  \param v The device_vector to move.
+   *  \param alloc The allocator to use by this device_vector.
+   */
+  device_vector(device_vector&& v, const Alloc& alloc)
+      : Parent(std::move(v), alloc)
+  {}
 
-    /*! Copy assign operator copies another \p device_vector with the same type.
-     *  \param v The \p device_vector to copy.
-     */
-    device_vector &operator=(const device_vector &v)
-    { Parent::operator=(v); return *this; }
+  /*! Copy assign operator copies another \p device_vector with the same type.
+   *  \param v The \p device_vector to copy.
+   */
+  device_vector& operator=(const device_vector& v)
+  {
+    Parent::operator=(v);
+    return *this;
+  }
 
-  #if THRUST_CPP_DIALECT >= 2011
-    /*! Move assign operator moves from another \p device_vector.
-     *  \param v The device_vector to move.
-     */
-     device_vector &operator=(device_vector &&v)
-     { Parent::operator=(std::move(v)); return *this; }
-  #endif // THRUST_CPP_DIALECT >= 2011
+  /*! Move assign operator moves from another \p device_vector.
+   *  \param v The device_vector to move.
+   */
+  device_vector& operator=(device_vector&& v)
+  {
+    Parent::operator=(std::move(v));
+    return *this;
+  }
 
-    /*! Copy constructor copies from an exemplar \p device_vector with different type.
-     *  \param v The \p device_vector to copy.
-     */
-   template<typename OtherT, typename OtherAlloc>
-   explicit device_vector(const device_vector<OtherT,OtherAlloc> &v)
-     :Parent(v) {}
+  /*! Copy constructor copies from an exemplar \p device_vector with different type.
+   *  \param v The \p device_vector to copy.
+   */
+  template <typename OtherT, typename OtherAlloc>
+  explicit device_vector(const device_vector<OtherT, OtherAlloc>& v)
+      : Parent(v)
+  {}
 
-    /*! Assign operator copies from an exemplar \p device_vector with different type.
-     *  \param v The \p device_vector to copy.
-     */
-    template<typename OtherT, typename OtherAlloc>
-    device_vector &operator=(const device_vector<OtherT,OtherAlloc> &v)
-    { Parent::operator=(v); return *this; }
+  /*! Assign operator copies from an exemplar \p device_vector with different type.
+   *  \param v The \p device_vector to copy.
+   */
+  template <typename OtherT, typename OtherAlloc>
+  device_vector& operator=(const device_vector<OtherT, OtherAlloc>& v)
+  {
+    Parent::operator=(v);
+    return *this;
+  }
 
-    /*! Copy constructor copies from an exemplar \c std::vector.
-     *  \param v The <tt>std::vector</tt> to copy.
-     */
-    template<typename OtherT, typename OtherAlloc>
-    device_vector(const std::vector<OtherT,OtherAlloc> &v)
-      :Parent(v) {}
+  /*! Copy constructor copies from an exemplar \c std::vector.
+   *  \param v The <tt>std::vector</tt> to copy.
+   */
+  template <typename OtherT, typename OtherAlloc>
+  device_vector(const std::vector<OtherT, OtherAlloc>& v)
+      : Parent(v)
+  {}
 
-    /*! Assign operator copies from an exemplar <tt>std::vector</tt>.
-     *  \param v The <tt>std::vector</tt> to copy.
-     */
-    template<typename OtherT, typename OtherAlloc>
-    device_vector &operator=(const std::vector<OtherT,OtherAlloc> &v)
-    { Parent::operator=(v); return *this;}
+  /*! Assign operator copies from an exemplar <tt>std::vector</tt>.
+   *  \param v The <tt>std::vector</tt> to copy.
+   */
+  template <typename OtherT, typename OtherAlloc>
+  device_vector& operator=(const std::vector<OtherT, OtherAlloc>& v)
+  {
+    Parent::operator=(v);
+    return *this;
+  }
 
-    /*! Copy construct from a \p vector_base whose element type is convertible
-     *  to \c T.
-     *
-     *  \param v The \p vector_base to copy.
-     */
-    template<typename OtherT, typename OtherAlloc>
-    device_vector(const detail::vector_base<OtherT,OtherAlloc> &v)
-      :Parent(v) {}
+  /*! Copy construct from a \p vector_base whose element type is convertible
+   *  to \c T.
+   *
+   *  \param v The \p vector_base to copy.
+   */
+  template <typename OtherT, typename OtherAlloc>
+  device_vector(const detail::vector_base<OtherT, OtherAlloc>& v)
+      : Parent(v)
+  {}
 
-    /*! Assign a \p vector_base whose element type is convertible to \c T.
-     *  \param v The \p vector_base to copy.
-     */
-    template<typename OtherT, typename OtherAlloc>
-    device_vector &operator=(const detail::vector_base<OtherT,OtherAlloc> &v)
-    { Parent::operator=(v); return *this; }
+  /*! Assign a \p vector_base whose element type is convertible to \c T.
+   *  \param v The \p vector_base to copy.
+   */
+  template <typename OtherT, typename OtherAlloc>
+  device_vector& operator=(const detail::vector_base<OtherT, OtherAlloc>& v)
+  {
+    Parent::operator=(v);
+    return *this;
+  }
 
-    /*! This constructor builds a \p device_vector from an intializer_list.
-     *  \param il The intializer_list.
-     */
-    device_vector(std::initializer_list<T> il)
-      :Parent(il) {}
-      
-    /*! This constructor builds a \p device_vector from an intializer_list.
-     *  \param il The intializer_list.
-     *  \param alloc The allocator to use by this device_vector.
-     */
-    device_vector(std::initializer_list<T> il, const Alloc &alloc)
-      :Parent(il, alloc) {}
-      
-    /*! Assign an \p intializer_list with a matching element type
-     *  \param il The intializer_list.
-     */
-    device_vector &operator=(std::initializer_list<T> il)
-    { Parent::operator=(il); return *this; }
+  /*! This constructor builds a \p device_vector from an intializer_list.
+   *  \param il The intializer_list.
+   */
+  device_vector(std::initializer_list<T> il)
+      : Parent(il)
+  {}
 
-    /*! This constructor builds a \p device_vector from a range.
-     *  \param first The beginning of the range.
-     *  \param last The end of the range.
-     */
-    template<typename InputIterator>
-    device_vector(InputIterator first, InputIterator last)
-      :Parent(first,last) {}
+  /*! This constructor builds a \p device_vector from an intializer_list.
+   *  \param il The intializer_list.
+   *  \param alloc The allocator to use by this device_vector.
+   */
+  device_vector(std::initializer_list<T> il, const Alloc& alloc)
+      : Parent(il, alloc)
+  {}
 
-    /*! This constructor builds a \p device_vector from a range.
-     *  \param first The beginning of the range.
-     *  \param last The end of the range.
-     *  \param alloc The allocator to use by this device_vector.
-     */
-    template<typename InputIterator>
-    device_vector(InputIterator first, InputIterator last, const Alloc &alloc)
-      :Parent(first,last,alloc) {}
+  /*! Assign an \p intializer_list with a matching element type
+   *  \param il The intializer_list.
+   */
+  device_vector& operator=(std::initializer_list<T> il)
+  {
+    Parent::operator=(il);
+    return *this;
+  }
+
+  /*! This constructor builds a \p device_vector from a range.
+   *  \param first The beginning of the range.
+   *  \param last The end of the range.
+   */
+  template <typename InputIterator>
+  device_vector(InputIterator first, InputIterator last)
+      : Parent(first, last)
+  {}
+
+  /*! This constructor builds a \p device_vector from a range.
+   *  \param first The beginning of the range.
+   *  \param last The end of the range.
+   *  \param alloc The allocator to use by this device_vector.
+   */
+  template <typename InputIterator>
+  device_vector(InputIterator first, InputIterator last, const Alloc& alloc)
+      : Parent(first, last, alloc)
+  {}
 
 // declare these members for the purpose of Doxygenating them
-// they actually exist in a derived-from class
+// they actually exist in a base class
 #if 0
     /*! \brief Resizes this vector to the specified number of elements.
      *  \param new_size Number of elements this vector should contain.
@@ -499,8 +529,8 @@ template<typename T, typename Alloc = thrust::device_allocator<T> >
  *  \p x The first \p device_vector of interest.
  *  \p y The second \p device_vector of interest.
  */
-template<typename T, typename Alloc>
-  void swap(device_vector<T,Alloc> &a, device_vector<T,Alloc> &b)
+template <typename T, typename Alloc>
+void swap(device_vector<T, Alloc>& a, device_vector<T, Alloc>& b)
 {
   a.swap(b);
 }
