@@ -22,9 +22,7 @@
 
 #include <thrust/detail/config.h>
 
-#if THRUST_CPP_DIALECT >= 2017
-#  include <type_traits>
-#endif
+#include <type_traits>
 
 THRUST_NAMESPACE_BEGIN
 
@@ -36,42 +34,19 @@ THRUST_NAMESPACE_BEGIN
  *  \{
  */
 
-#if THRUST_CPP_DIALECT >= 2011
-
 /*! \brief Utility trait that maps a sequence of any types to the type void.
  */
-template <typename...> struct voider
+template <typename...>
+struct THRUST_DEPRECATED_BECAUSE("Use std::void_t") voider
 {
   /*! \brief The resulting type (always void). */
   using type = void;
 };
 
-#if THRUST_CPP_DIALECT >= 2017
-using std::void_t;
-#else
-template <typename... Ts> using void_t = typename voider<Ts...>::type;
-#endif
-
-#else // Older than C++11.
-
-template <
-  typename = void
-, typename = void
-, typename = void
-, typename = void
-, typename = void
-, typename = void
-, typename = void
-, typename = void
-, typename = void
-, typename = void
->
-struct voider
-{
-  typedef void type;
-};
-
-#endif
+/*! \brief Utility alias that maps a sequence of types to the type void.
+ */
+template <typename... Ts>
+using void_t THRUST_DEPRECATED_BECAUSE("Use std::void_t") = void;
 
 /*! \} // type traits
  */
